//#include <GLFW/glfw3.h>

#include <stdio.h>
#include <string.h>
#include <cassert>
#include <stdlib.h>
#include <sys/stat.h>
#include <glad/glad.h>

#define CONST_READSHADER_MAX_FN_LEN 256
#define CONST_READSHADER_MAX_FN_SIZE 32*1024

//#define LPR__VERBOSE_SHADER

int readshader(const char *fn, GLchar** pshdr_source) {
	char shader_fn[CONST_READSHADER_MAX_FN_LEN];
	assert(strlen(fn) + 9 < CONST_READSHADER_MAX_FN_LEN);
	struct stat status_buffer;

	GLchar *shdr_source;

	snprintf(shader_fn, CONST_READSHADER_MAX_FN_LEN, "res/shaders/%s", fn);

	#ifdef LPR__VERBOSE_SHADER
	printf("Load: '%s'\n", shader_fn);
	#endif

	if (stat(shader_fn, &status_buffer) != 0) {
		printf("Failed to stat file '%s'\n", shader_fn);
		return -1;
	}

	assert(status_buffer.st_size < CONST_READSHADER_MAX_FN_SIZE-1);

	FILE *fh = fopen(shader_fn, "r");
	assert(fh != NULL);

	shdr_source = (GLchar *)malloc(CONST_READSHADER_MAX_FN_SIZE);
	assert(shdr_source != NULL);

	size_t read_bytes = fread((void *)shdr_source, sizeof(char), 
		CONST_READSHADER_MAX_FN_SIZE-1, fh);
	assert(read_bytes < CONST_READSHADER_MAX_FN_SIZE-1);
	shdr_source[read_bytes] = '\0';

	#ifdef LPR__VERBOSE_SHADER
	puts(shdr_source);
	#endif

	fclose(fh);
	assert(shdr_source != NULL);
		
	*pshdr_source = shdr_source;
	
	return 0;
}

void freeshader(void *pshdr_source) {
	assert(pshdr_source != NULL);
	free(pshdr_source);
}

